#
# spec file for package python-pybtex
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oname   pybtex
Name:           python-pybtex
Version:        0.24.0
Release:        3.3
Summary:        BibTeX-compatible Bibliography Processor in Python
License:        MIT
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://pybtex.org/
Source0:        https://files.pythonhosted.org/packages/source/p/pybtex/pybtex-%{version}.tar.gz
# https://bitbucket.org/pybtex-devs/pybtex/commits/6afabe217af95995d595de493cf9bc5120f85ca7
Patch0:         python-pybtex-no-six.patch
BuildRequires:  %{python_module PyYAML >= 3.0.1}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module latexcodec}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-latexcodec
Requires:       python-pyparsing
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Pybtex is a BibTeX-compatible bibliography processor written in Python which
can produce formatted bibliographies in different, customizable formats. It
supports both native BibTeX style files and styles written in Python and
accepts BibTeX, BibTeXML, and a custom YAML-based bibligraphy input format and
can output LaTeX, HTML, and plain text.

Furthermore, Pybtex provides an interface for Python applications which need to
process the above formats.

%prep
%autosetup -p1 -n %{oname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
# install man
for man in %{oname} %{oname}-convert %{oname}-format ; do
  install -Dpm 0644 docs/man1/${man}.1 %{buildroot}%{_mandir}/man1/${man}.1
done
%python_clone -a %{buildroot}%{_mandir}/man1/%{oname}-format.1
%python_clone -a %{buildroot}%{_mandir}/man1/%{oname}-convert.1
%python_clone -a %{buildroot}%{_mandir}/man1/%{oname}.1
%python_clone -a %{buildroot}%{_bindir}/%{oname}-format
%python_clone -a %{buildroot}%{_bindir}/%{oname}-convert
%python_clone -a %{buildroot}%{_bindir}/%{oname}

%check
%pytest

%post
%python_install_alternative %{oname}-format.1
%python_install_alternative %{oname}-convert.1
%python_install_alternative %{oname}.1
%python_install_alternative %{oname}-format
%python_install_alternative %{oname}-convert
%python_install_alternative %{oname}

%postun
%python_uninstall_alternative %{oname}-format.1
%python_uninstall_alternative %{oname}-convert.1
%python_uninstall_alternative %{oname}.1
%python_uninstall_alternative %{oname}-format
%python_uninstall_alternative %{oname}-convert
%python_uninstall_alternative %{oname}

%files %{python_files}
%python_alternative %{_mandir}/man1/%{oname}-format.1%{ext_man}
%python_alternative %{_mandir}/man1/%{oname}-convert.1%{ext_man}
%python_alternative %{_mandir}/man1/%{oname}.1%{ext_man}
%python_alternative %{_bindir}/%{oname}-format
%python_alternative %{_bindir}/%{oname}-convert
%python_alternative %{_bindir}/%{oname}
%{python_sitelib}/*

%changelog
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Tue Mar  7 2023 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://bitbucket.org/pybtex-devs/pybtex/commits/6afabe217af95995d595de493cf9bc5120f85ca7
  + python-pybtex-no-six.patch
* Thu Sep 30 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.24.0:
  * Added support for sup and sub tags to LaTeX and Markdown backends.
  * Added support for @online entries and the urldate field.
  * Fixed bugs in the example plugin.
  * Fixed bad get_default_encoding() call.
  * Reimplemented pybtex.utils.OrderedCaseInsensitiveDict using
    collections.OrderedDict (so it has a __delitem__).
  * unsrt.py now supports type when formatting phdthesis.
  * Added from_string to pybtex.database.BibliographyData.
  * Added from_string and to_string to pybtex.database.Entry.
  * Preserve order in pybtex.utils.OrderedCaseInsensitiveDict.__repr__.
  * Fixed entries with duplicate keys being removed during sorting.
  * Fixed handling of duplicate person fields
  * Use xml.etree.ElementTree instead of the deprecated cElementTree.
  * Import base classes from collections.abc instead of collections.
  * Use __iter__ instead of deprecated Element.getchildren().
- Switch to using pytest to run tests, and run the testsuite.
* Fri Oct  2 2020 Martin Pluskal <mpluskal@suse.com>
- Do not ship tests
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.22.2:
  * Fixed compatibility with Python 2 and older versions of Python 3.
  * Fixed non-working ``--backend`` option with ``pybtex -l python``.
  * Fixed handling of duplicate fields in ``.bib`` biles.
  * BibTeX parser is now up to 10%% faster on some files.
  * Fixed parsing of names with ``\~`` characters.
  * Fixed formatting proceedings without an ``editor`` field in ``unsrt.py``.
  * In case of too many braces in a BibTeX string, ``PybtexSyntaxError`` is now raised instead
  * Dropped ``2to3``, made the code compatible with both Python 2 and 3 with Six_.
  * Moved tests outside of the ``pybtex`` package.
  * Fixed searching in docs with recent versions of Sphinx_.
  * API: renamed ``bibtex.BibTeXEntryIterator`` to ``bibtex.LowLevelParser`` for clarity.
  * API: removed confusing usage of ``Person.text`` in ``tempate.names``.
  * API: ``Entry.fields`` does not automagically look for cross-referenced entries
  +  anymore.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan  4 2018 mpluskal@suse.com
- Update to version 0.21:
  * BibTeX writer now uses latexcodec to encode characters that are
    not directly supported by the output encoding. Thanks, Hong Xu!
  * HTML backend: {braced stings} are now wrapped with
    <span class="bibtex-protected"> to enable custom CSS styling.
  * unsrt.py: DOI, PubMed and Arxiv links now use HTTPS instead of
    HTTP.
  * unsrt.py: URLs with percent characters are now formatted
    correctly.
  * unsrt.py: short page / volume / chapter numbers are now joined
    with a non-breaking space, like in BibTeX.
  * unsrt.py: inbook now uses the editor field if the author field
    is missing, like in BibTeX.
  * unsrt.py: the words “volume” and “pages” in the beginning of
    the sentence are now capitalized, like in BibTeX.
  * unsrt.py: removed unnecessary period between the book title and
    the comma in inbook.
  * LaTeX backend: fix encoding tilde ("~") characters with newer
    versions of latexcodec.
  * Fix splitting names with escaped space ("\ ") characters.
- Convert to singlespec
* Mon Dec  7 2015 nemysis@openSUSE.org
- Update to 0.19, announce message:
  - Added Markdown output format (contributed by Jorrit Wronski).
  - Incorrectly formatted author and editor names now result in warnings instead of errors,
  unless ``--strict`` mode is enabled.
  - Fixed HTML escaping.
  - Fixed parsing nested ``.aux`` files.
  - Fixed splitting names separated by non-lowercase ``" and "``.
  - Fixed line numbers in error messages when parsing strings with DOS/Windows line breaks.
  - Fixed compatibility with BibTeX when parsing certain weird "von" names.
  - Removed excessive trailing newline from ``.bib`` output.
  - Text wrapping now works exactly as in BibTeX.
  - Added new API for :doc:`reading and writing bibliography data <api/parsing>`.
  - Pythonic styles: reworked and extended the :ref:`rich text API <rich-text>`.
  - Pythonic styles: added ``strong``, ``i``, ``b``, ``tt`` tags, renamed the old
  ``emph`` tag to ``em``.
  - Pythonic styles: the ``author_year_title`` style now returns ``""`` instead of ``None``
  (fixes unorderable types error in Python 3).
  - Ported the documentation_ to Sphinx_.
  Thanks to Jorrit Wronski and Matthias Troffaes for their fixes and improvements!
- Add BuildRequires, changed by Upstream for python-PyYAML and
  python-nose
- Remove obsolete Sed, changed by Upstream
- Change Documentation, changed by Upstream
* Sun Jul 12 2015 nemysis@gmx.ch
- Use %%{oname} instead of pybtex
- Change Url from SourceForge to http://pybtex.org
- Add python-pybtex-rpmlintrc, executable script in documentation
- Use check for openSUSE %%if 0%%{?suse_version}
- Remove Recommends for non existent python-yaml
- Split out doc and add doc into subpackages
- Remove BuildRequires for ed, use sed instead
- Add sed, Fix URL
- Change Man Pages, add pybtex-format
- Add examples to Documentation
* Tue Aug 26 2014 gber@opensuse.org
- update to version 0.18
  - Pybtex is now fully case-insensitive (like BibTeX). As a
    consequence, IEEEtran styles now work corretly.
  - Added ``--preserve-case`` optoin to ``pybtex-convert`` (by
    default all identifiers are converted to lower case).
  - An erorr is reported if two citations have the same key but
    different case, like in BibTeX. (Example: ddt1999 and DDT1999).
  - Fixed parsing unused bibliography entries with strings
    containing @ characters.
  - ``entry.max$`` constant is now set to 250, ``global.max$`` is
    set to 20000, like in BibTeX.
  - Added ``--strict`` option to ``pybtex-convert`` and
    ``pybtex-format`` (turns warning to errors).
  - Strict mode is now enabled by default when using pybtex as a
    library (exceptions are raised on all errors instead of just
    printing warnings to stderr).
    Non-strict error handling is still enabled when using pybtex
    from the command line, for compatibility with BibTeX. Use
    ``--strict`` option if you don't like this.
  - Added missing pybtex-format manpage.
* Mon May 26 2014 gber@opensuse.org
- update to version 0.17
  - Added pybtex-format utility for formatting bibliography files
    as HTML, LaTeX, and other supported human-readable formats.
  - Added --strict command line option (all warnings become
    errors).
  - Added alpha label style, and alpha and unsrtalpha formatting
    styles.
  - Added support for url, eprint, doi, and pubmed fields in unsrt
    style.
  - Names with hyphens are now abbreviated correctly
    ("Jean-Baptiste" becomes "J.-B.").
  - width$ now uses cmr10 font metrics, like in BibTeX. Non-latin
    characters are also supported.
  - Pythonic style engine now supports @preamble commands.
  - Warning on missing fields are now more human-readable.
  - When writing BibTeX files, put entry key on the same line with
    entry type. Fixes warnings in Jabref.
  - When using multiple .bib files, macros defined in earlier files
    are available in subsequent ones (like in BibTeX).
  - Fixed parsing .bst files with lines consisting of a single %%
    character.
  - Fixed sorting entries without author in author_year_title
    sorting style.
  - Fixed broken CaseInsensitiveDict.get().
  - CaseInsensitiveDict is now pickleable.
  - Added support for registering plugins at runtime with
    pybtex.plugin.register_plugin() - useful for using pybtex as a
    library.
* Wed May 16 2012 gber@opensuse.org
- update to version 0.16
  - BibTeX .bib and .bst parsers were completely rewritten; they
    are now much faster and more BibTeX-compatible
  - syntax errors and undefined strings in .bib files now result in
    warnings instead of errors, like in BibTeX
  - unused entries in .bib files are now skipped, like in BibTeX
  - the case of entry keys is now preserved (in previous versions
    they were converted to lowercase)
  - pythonic style engine now supports sorting
  - pythonic style engine: fixed nested optional() blocks
  - fixed parsing of some names with a Last part but no von part
  - fixed processing of brace-level-one "special characters" in
    purify$ BibTeX built-in function
  - added proper error messages on encoding errors in .bib files
  - the default encoding is now UTF-8 on all platforms
  - pybtex-convert now preserves the order of entries in BibTeX and
    BibTeXML files
  - fixed first_of behavior when non-empty child is followed by a
    child that has a missing field
  - fixed crossref lookups when key is not lower case
  - completed unsrt and plain python styles: they now contain all
    entry types
  - added doctree backend for rendering into a tree of docutils
    nodes
  - added support for non-string backends
* Mon Jun 13 2011 gber@opensuse.org
- update to version 0.15
  - changed license from GPL-3 to MIT
  - when parsing multiple BibTeX files, macros defined in earlier
    files are now available to all subsequent files, like in BibTeX
  - BibTeX .bst interpreter now prints warnings on missing entries,
    like BibTeX, instead of raising a KeyError
  - call.type$ BibTeX built-in function now uses default.entry for
    unknown entry types, like in BibTeX
  - substring$ now accepts start=0 and returns an empty string.
  - added more detailed error messages for already defined
    variables in .bst files
  - bugfixes
* Sun Jan  9 2011 gber@opensuse.org
- add documentation
* Sun Jan  9 2011 gber@opensuse.org
- initial packaging
